Rendering Contexts
==================

These are the top-level rendering contexts available in ``yt_idv``.

.. toctree::

.. autofunction:: yt_idv.rendering_contexts.render_context

.. autoclass:: yt_idv.rendering_contexts.pyglet_context.PygletRenderingContext
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: yt_idv.rendering_contexts.egl_context.EGLRenderingContext
   :members:
   :undoc-members:
   :show-inheritance:
